@@ -5,7 +5,7 @@ use Object::Pad;
 use Getopt::Long qw(GetOptions);
 
 use lib 'lib';
-use Diary;
+use Standup::Diary;
 
 my $data_dir = 'data';
 my $project_name = 'Diary';
@@ -14,8 +14,8 @@ GetOptions ("data-dir:s" => \$data_dir,
             "project-name:s"   => \$project_name)
 or die("Error in command line arguments\n");
 
-my $diary = Diary->new( data_dir => $data_dir, project_name => $project_name );
+my $diary = Standup::Diary->new( data_dir => $data_dir, project_name => $project_name );
 
 $diary->write;
 
-#say $diary->render;
+1;
